@@ -7,7 +7,7 @@ use Sub::Name;
 use UNIVERSAL::require;
 
 
-our $VERSION = '0.06';
+our $VERSION = '0.08';
 
 
 use base 'Exporter';
@@ -61,8 +61,6 @@ sub PIPE {
 
 __END__
 
-
-
 =head1 NAME
 
 Text::Pipe - Common text filter API
@@ -114,25 +112,33 @@ corresponding pipe.
 
 =over 4
 
+=item new
 
+    my $pipe = Text::Pipe->new('List::First', code => { $_ < 7 });
+
+Constructs a new pipe. The first argument is the pipe segment type - in the
+example above a C<Text::Pipe::List::First> would be constructed. The remaining
+arguments are passed to that segment's constructor.
+
+=item def_pipe
+
+    Text::Pipe->def_pipe('Foobar', sub { lc $_[1] });
+    my $pipe_lowercase = Text::Pipe->new('Foobar');
+    is($pipe_lowercase->filter('A TEST'), 'a test', 'lowercase pipe');
+
+This method provides a lightweight way to define a new pipe segment class. The
+first argument is the segment type - in the example above, a new segment class
+C<Text::Pipe::Foobar> would be defined. The second argument is a coderef that
+acts as the segment's filter. The segment class will subclass
+C<Text::Pipe::Base>.
 
 =back
 
-=head1 TAGS
-
-If you talk about this module in blogs, on del.icio.us or anywhere else,
-please use the C<textpipe> tag.
-
-=head1 VERSION 
-                   
-This document describes version 0.06 of L<Text::Pipe>.
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<<bug-text-pipe@rt.cpan.org>>, or through the web interface at
+Please report any bugs or feature requests through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -142,20 +148,23 @@ See perlmodinstall for information and options on installing Perl modules.
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you. Or see L<http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
 
-=head1 AUTHOR
+The development version lives at L<http://github.com/hanekomu/text-pipe/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
+=head1 AUTHORS
 
 Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 by Marcel GrE<uuml>nauer
+Copyright 2007-2008 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-
 =cut
 
